@@ -29,13 +29,13 @@ namespace Aws
         static const char AP_SOUTHEAST_4[] = "ap-southeast-4"; // Asia Pacific (Melbourne)
         static const char AP_SOUTHEAST_5[] = "ap-southeast-5"; // Asia Pacific (Malaysia)
         static const char AP_SOUTHEAST_7[] = "ap-southeast-7"; // Asia Pacific (Thailand)
-        static const char AWS_CN_GLOBAL[] = "aws-cn-global"; // AWS China global region
-        static const char AWS_GLOBAL[] = "aws-global"; // AWS Standard global region
-        static const char AWS_ISO_B_GLOBAL[] = "aws-iso-b-global"; // AWS ISOB (US) global region
-        static const char AWS_ISO_E_GLOBAL[] = "aws-iso-e-global"; // AWS ISOE (Europe) global region
-        static const char AWS_ISO_F_GLOBAL[] = "aws-iso-f-global"; // AWS ISOF global region
-        static const char AWS_ISO_GLOBAL[] = "aws-iso-global"; // AWS ISO (US) global region
-        static const char AWS_US_GOV_GLOBAL[] = "aws-us-gov-global"; // AWS GovCloud (US) global region
+        static const char AWS_CN_GLOBAL[] = "aws-cn-global"; // aws-cn global region
+        static const char AWS_GLOBAL[] = "aws-global"; // aws global region
+        static const char AWS_ISO_B_GLOBAL[] = "aws-iso-b-global"; // aws-iso-b global region
+        static const char AWS_ISO_E_GLOBAL[] = "aws-iso-e-global"; // aws-iso-e global region
+        static const char AWS_ISO_F_GLOBAL[] = "aws-iso-f-global"; // aws-iso-f global region
+        static const char AWS_ISO_GLOBAL[] = "aws-iso-global"; // aws-iso global region
+        static const char AWS_US_GOV_GLOBAL[] = "aws-us-gov-global"; // aws-us-gov global region
         static const char CA_CENTRAL_1[] = "ca-central-1"; // Canada (Central)
         static const char CA_WEST_1[] = "ca-west-1"; // Canada West (Calgary)
         static const char CN_NORTH_1[] = "cn-north-1"; // China (Beijing)
